@@ -56,7 +56,6 @@ class WebOsClient:
         self.port = 3000
         self.key_file_path = key_file_path
         self.client_key = client_key
-        self.web_socket = None
         self.command_count = 0
         self.timeout_connect = timeout_connect
         self.ping_interval = ping_interval
@@ -116,9 +115,7 @@ class WebOsClient:
     async def connect(self):
         if not self.is_connected():
             self.connect_result = asyncio.Future()
-            self.connect_task = asyncio.create_task(
-                self.connect_handler(self.connect_result)
-            )
+            self.connect_task = asyncio.create_task(self.connect_handler(self.connect_result))
         return await self.connect_result
 
     async def disconnect(self):
@@ -142,7 +139,6 @@ class WebOsClient:
         return handshake
 
     async def connect_handler(self, res):
-
         ws = None
         try:
             ws = await asyncio.wait_for(
@@ -171,12 +167,10 @@ class WebOsClient:
             raw_response = await ws.recv()
             response = json.loads(raw_response)
 
-            if (
-                response["type"] == "response"
-                and response["payload"]["pairingType"] == "PROMPT"
-            ):
+            if (response["type"] == "response" and response["payload"]["pairingType"] == "PROMPT"):
                 raw_response = await ws.recv()
                 response = json.loads(raw_response)
+
                 if response["type"] == "registered":
                     self.client_key = response["payload"]["client-key"]
                     await self.storage.set_key(self.ip, self.client_key)
@@ -184,50 +178,45 @@ class WebOsClient:
             if not self.client_key:
                 raise PyLGTVPairException("Unable to pair")
 
-            self.callbacks = {}
-            self.futures = {}
+            self.handler_tasks.add(asyncio.create_task(self.consumer_handler(ws)))
+
+            if self.ping_interval is not None and self.ping_timeout is not None:
+                self.handler_tasks.add(asyncio.create_task(self.ping_handler(ws)))
 
-            self.handler_tasks.add(
-                asyncio.create_task(
-                    self.consumer_handler(ws, self.callbacks, self.futures)
-                )
-            )
-            if self.ping_interval is not None:
-                self.handler_tasks.add(
-                    asyncio.create_task(
-                        self.ping_handler(ws, self.ping_interval, self.ping_timeout)
-                    )
-                )
             self.connection = ws
 
-            self.doStateUpdate = False
             if self.states:
+                selectedStates = self.states
                 # set static states, possible values: ["system_info", "software_info"]
-                staticStates = self.states.intersection(self.STATIC_STATES)
+                staticStates = selectedStates.intersection(self.STATIC_STATES)
                 if staticStates:
                     # e.g.: [self._system_info] = await asyncio.gather(self.get_system_info())
                     for stateElem in staticStates:
                         stateResult = await asyncio.gather(getattr(self, f'get_{stateElem}')())
                         setattr(self, f'_{stateElem}', (stateResult or [None])[0])
-                        self.states.remove(stateElem)
+                        selectedStates.remove(stateElem)
 
                 # subscribe to state updates, avoid partial updates during initial subscription
                 # possible values: ["power", "current_app", "muted", "volume", "apps", "inputs",
                 #                   "sound_output", "picture_settings"]
                 subscribe_coros = set()
-                if self.states:
+                if selectedStates:
                     # e.g.: subscribe_coros.add(self.subscribe_power(self.set_power_state))
-                    for stateElem in self.states:
+                    for stateElem in selectedStates:
                         subscriber = f'subscribe_{stateElem}'
                         setter = f'set_{stateElem}_state'
+
                         if callable(getattr(self, subscriber, None)) and callable(getattr(self, setter, None)):
                             subscribe_coros.add(getattr(self, subscriber)(getattr(self, setter)))
 
                 if subscribe_coros:
                     subscribe_tasks = set()
+
                     for coro in subscribe_coros:
                         subscribe_tasks.add(asyncio.create_task(coro))
+
                     await asyncio.wait(subscribe_tasks)
+
                     for task in subscribe_tasks:
                         try:
                             task.result()
@@ -237,7 +226,9 @@ class WebOsClient:
             # set placeholder power state if not available
             if not self._power_state:
                 self._power_state = {"state": "Unknown"}
+
             self.doStateUpdate = True
+
             if self.state_update_callbacks:
                 await self.do_state_update_callbacks()
 
@@ -261,15 +252,32 @@ class WebOsClient:
 
             if ws is not None:
                 closeout.add(asyncio.create_task(ws.close()))
+
             if self.input_connection is not None:
                 closeout.add(asyncio.create_task(self.input_connection.close()))
 
+            for callback in self.state_update_callbacks:
+                closeout.add(callback(self))
+
+            if closeout:
+                closeout_task = asyncio.create_task(asyncio.wait(closeout))
+
+                while not closeout_task.done():
+                    try:
+                        await asyncio.shield(closeout_task)
+                    except asyncio.CancelledError:
+                        pass
+
             self.connection = None
             self.input_connection = None
-
+            self.connect_task = None
+            self.connect_result = None
+            self.handler_tasks = set()
+            self.callbacks = {}
+            self.futures = {}
+            self.state_update_callbacks = []
             self.doStateUpdate = False
 
-            self.storage = None
             self._power_state = {}
             self._current_appId = None
             self._muted = None
@@ -285,27 +293,13 @@ class WebOsClient:
             self._sound_output = None
             self._picture_settings = None
 
-            for callback in self.state_update_callbacks:
-                closeout.add(callback(self))
-
-            if closeout:
-                closeout_task = asyncio.create_task(asyncio.wait(closeout))
-
-                while not closeout_task.done():
-                    try:
-                        await asyncio.shield(closeout_task)
-                    except asyncio.CancelledError:
-                        pass
-
-    async def ping_handler(self, ws, interval, timeout):
+    async def ping_handler(self, ws):
         try:
             while True:
-                await asyncio.sleep(interval)
-                # In the "Suspend" state the tv can keep a connection alive, but will not respond to pings
-                if self._power_state.get("state") != "Suspend":
+                await asyncio.sleep(self.ping_interval)
+                if self.is_on:
                     ping_waiter = await ws.ping()
-                    if timeout is not None:
-                        await asyncio.wait_for(ping_waiter, timeout=timeout)
+                    await asyncio.wait_for(ping_waiter, timeout=self.ping_timeout)
         except (
             asyncio.TimeoutError,
             asyncio.CancelledError,
@@ -325,18 +319,18 @@ class WebOsClient:
         except asyncio.CancelledError:
             pass
 
-    async def consumer_handler(self, ws, callbacks={}, futures={}):
-
+    async def consumer_handler(self, ws):
         callback_queues = {}
         callback_tasks = {}
 
         try:
             async for raw_msg in ws:
-                if callbacks or futures:
+                if self.callbacks or self.futures:
                     msg = json.loads(raw_msg)
                     uid = msg.get("id")
                     callback = self.callbacks.get(uid)
                     future = self.futures.get(uid)
+
                     if callback is not None:
                         if uid not in callback_tasks:
                             queue = asyncio.Queue()
@@ -371,6 +365,13 @@ class WebOsClient:
                     except asyncio.CancelledError:
                         pass
 
+    def __output_result(self, res, jsonOutput=False, sortKeys=True, indent=4):
+        """Output result as it is (e.g. dictionary) or JSON string."""
+        if jsonOutput:
+            return json.dumps(res, sort_keys=sortKeys, indent=indent)
+        else:
+            return res
+
     # manage state
     @property
     def power_state(self):
@@ -471,7 +472,9 @@ class WebOsClient:
     async def set_power_state(self, payload):
         self._power_state = {"state": payload.get("state", "Unknown")}
 
-        if self.state_update_callbacks and self.doStateUpdate:
+        if not self.is_on:
+            await self.disconnect()
+        elif self.state_update_callbacks and self.doStateUpdate:
             await self.do_state_update_callbacks()
 
     async def set_current_app_state(self, appId):
@@ -513,7 +516,6 @@ class WebOsClient:
 
     async def set_current_channel_state(self, channel):
         """Set current channel state variable.  This function also handles the channel info subscription, since that call may fail if channel information is not available when it's called."""
-
         self._current_channel = channel
 
         if self._channel_info is None:
@@ -599,19 +601,23 @@ class WebOsClient:
         if uid is None:
             uid = self.command_count
             self.command_count += 1
+
         res = asyncio.Future()
         self.futures[uid] = res
+
         try:
             await self.command(cmd_type, uri, payload, uid)
         except (asyncio.CancelledError, PyLGTVCmdException):
             del self.futures[uid]
             raise
+
         try:
             response = await res
         except asyncio.CancelledError:
             if uid in self.futures:
                 del self.futures[uid]
             raise
+
         del self.futures[uid]
 
         payload = response.get("payload")
@@ -638,6 +644,7 @@ class WebOsClient:
         uid = self.command_count
         self.command_count += 1
         self.callbacks[uid] = callback
+
         try:
             return await self.request(
                 uri, payload=payload, cmd_type="subscribe", uid=uid
@@ -664,12 +671,9 @@ class WebOsClient:
                     timeout=self.timeout_connect,
                 )
 
-                if self.ping_interval is not None:
-                    self.handler_tasks.add(
-                        asyncio.create_task(
-                            self.ping_handler(inputws, self.ping_interval, self.ping_timeout)
-                        )
-                    )
+                if self.ping_interval is not None and self.ping_timeout is not None:
+                    self.handler_tasks.add(asyncio.create_task(self.ping_handler(inputws)))
+
                 self.input_connection = inputws
 
             if self.input_connection is None:
@@ -685,7 +689,6 @@ class WebOsClient:
 
     async def button(self, name, checkValid=True):
         """Send button press command."""
-
         if checkValid and str(name) not in btn.BUTTONS:
             raise ValueError(
                 f"button {name} is not valid, use checkValid=False to try a new one"
@@ -696,19 +699,16 @@ class WebOsClient:
 
     async def move(self, dx, dy, down=0):
         """Send cursor move command."""
-
         message = f"type:move\ndx:{dx}\ndy:{dy}\ndown:{down}\n\n"
         await self.input_command(message)
 
     async def click(self):
         """Send cursor click command."""
-
         message = f"type:click\n\n"
         await self.input_command(message)
 
     async def scroll(self, dx, dy):
         """Send scroll command."""
-
         message = f"type:scroll\ndx:{dx}\ndy:{dy}\n\n"
         await self.input_command(message)
 
@@ -740,19 +740,19 @@ class WebOsClient:
         return await self.subscribe(callback, ep.GET_POWER_STATE)
 
     # Apps
-    async def get_apps(self):
+    async def get_apps(self, jsonOutput=False):
         """Return all apps."""
         res = await self.request(ep.GET_APPS)
-        return res.get("launchPoints")
+        return self.__output_result(res.get("launchPoints"), jsonOutput)
 
     async def subscribe_apps(self, callback):
         """Subscribe to changes in available apps."""
         return await self.subscribe(callback, ep.GET_APPS)
 
-    async def get_apps_all(self):
+    async def get_apps_all(self, jsonOutput=False):
         """Return all apps, including hidden ones."""
         res = await self.request(ep.GET_APPS_ALL)
-        return res.get("apps")
+        return self.__output_result(res.get("apps"), jsonOutput)
 
     async def get_current_app(self):
         """Get the current app id."""
@@ -761,7 +761,6 @@ class WebOsClient:
 
     async def subscribe_current_app(self, callback):
         """Subscribe to changes in the current app id."""
-
         async def current_app(payload):
             await callback(payload.get("appId"))
 
@@ -784,22 +783,23 @@ class WebOsClient:
         return await self.request(ep.LAUNCHER_CLOSE, {"id": app})
 
     # Services
-    async def get_services(self):
+    async def get_services(self, jsonOutput=False):
         """Get all services."""
         res = await self.request(ep.GET_SERVICES)
-        return res.get("services")
+        return self.__output_result(res.get("services"), jsonOutput)
 
-    async def get_software_info(self):
+    async def get_software_info(self, jsonOutput=False):
         """Return the current software status."""
-        return await self.request(ep.GET_SOFTWARE_INFO)
+        res = await self.request(ep.GET_SOFTWARE_INFO)
+        return self.__output_result(res, jsonOutput)
 
     async def get_system_info(self):
         """Return the system information."""
         return await self.request(ep.GET_SYSTEM_INFO)
 
-    async def get_hello_info(self):
+    async def get_hello_info(self, jsonOutput=False):
         """Return hello information."""
-        return self._hello_info
+        return self.__output_result(self._hello_info, jsonOutput)
 
     async def power_off(self):
         """Power off TV."""
@@ -807,6 +807,7 @@ class WebOsClient:
         # protect against turning tv back on if it is off
         power_state = await self.get_power_state()
         self._power_state = {"state": power_state.get("state", "Unknown")}
+
         if not self.is_on:
             return
 
@@ -815,7 +816,7 @@ class WebOsClient:
         await self.command("request", ep.POWER_OFF)
 
     async def power_on(self):
-        """Play media."""
+        """Power on TV."""
         return await self.request(ep.POWER_ON)
 
     async def turn_screen_off(self, webos_ver=""):
@@ -850,14 +851,13 @@ class WebOsClient:
         return await self.request(ep.SET_3D_OFF)
 
     # Inputs
-    async def get_inputs(self):
+    async def get_inputs(self, jsonOutput=False):
         """Get all inputs."""
         res = await self.request(ep.GET_INPUTS)
-        return res.get("devices")
+        return self.__output_result(res.get("devices"), jsonOutput)
 
     async def subscribe_inputs(self, callback):
         """Subscribe to changes in available inputs."""
-
         async def inputs(payload):
             await callback(payload.get("devices"))
 
@@ -883,7 +883,6 @@ class WebOsClient:
 
     async def subscribe_muted(self, callback):
         """Subscribe to changes in the current mute status."""
-
         async def muted(payload):
             await callback(payload.get("mute"))
 
@@ -900,7 +899,6 @@ class WebOsClient:
 
     async def subscribe_volume(self, callback):
         """Subscribe to changes in the current volume."""
-
         async def volume(payload):
             await callback(payload.get("volumeStatus", payload).get("volume"))
 
@@ -941,14 +939,13 @@ class WebOsClient:
         """Channel down."""
         return await self.request(ep.TV_CHANNEL_DOWN)
 
-    async def get_channels(self):
+    async def get_channels(self, jsonOutput=False):
         """Get list of tv channels."""
         res = await self.request(ep.GET_TV_CHANNELS)
-        return res.get("channelList")
+        return self.__output_result(res.get("channelList"), jsonOutput)
 
     async def subscribe_channels(self, callback):
         """Subscribe to list of tv channels."""
-
         async def channels(payload):
             await callback(payload.get("channelList"))
 
@@ -962,9 +959,10 @@ class WebOsClient:
         """Subscribe to changes in the current tv channel."""
         return await self.subscribe(callback, ep.GET_CURRENT_CHANNEL)
 
-    async def get_channel_info(self):
+    async def get_channel_info(self, jsonOutput=False):
         """Get the current channel info."""
-        return await self.request(ep.GET_CHANNEL_INFO)
+        res = await self.request(ep.GET_CHANNEL_INFO)
+        return self.__output_result(res, jsonOutput)
 
     async def subscribe_channel_info(self, callback):
         """Subscribe to current channel info."""
@@ -981,7 +979,6 @@ class WebOsClient:
 
     async def subscribe_sound_output(self, callback):
         """Subscribe to changes in current audio output."""
-
         async def sound_output(payload):
             await callback(payload.get("soundOutput"))
 
@@ -1071,30 +1068,48 @@ class WebOsClient:
         """Input button."""
         return await self.luna_request(ep.LUNA_SHOW_INPUT_PICKER, {})
 
-    async def set_current_picture_mode(self, pic_mode):
-        """Set picture mode for current input, dynamic range and 3d mode.
+    async def set_device_info(self, input, icon, label):
+        """Set device info. It can be used to switch between PC and non-PC modes.
+
+        Inputs: "HDMI_1", "HDMI_2", "HDMI_3", "HDMI_4"
+        Icons:  "HDMI_1", "HDMI_2", "HDMI_3", "HDMI_4", "satellite", "settopbox",
+                "dvd", "bluray", "hometheater", "gameconsole",
+                "streamingbox", "camera", "mobile", "pc"
+        Labels: "HDMI 1", "HDMI 2", "HDMI 3", "HDMI 4", "Satellite", "Set-Top Box",
+                "DVD Player", "Blu-ray Player", "Home Theatre", "Game Console",
+                "Streaming Box", "Generic Camera", "Mobile Device", "PC"
+        """
+
+        params = {"id": input, "icon": f"{icon}.png", "label": label}
+
+        return await self.luna_request(ep.LUNA_SET_DEVICE_INFO, params)
+
+    async def set_current_picture_mode(self, pic_mode, category="picture"):
+        """Set picture mode for current category, input, dynamic range and 3d mode (OLED C1).
 
         Known picture modes are: cinema, eco, expert1, expert2, game,
-        normal, photo, sports, technicolor, filmMaker, vivid, hdrEffect, hdrCinema,
-        hdrCinemaBright, hdrExternal, hdrGame, hdrStandard, hdrTechnicolor, hdrFilmMaker,
+        normal, photo, sports, filmMaker, vivid, hdrCinema,
+        hdrCinemaBright, hdrExternal, hdrGame, hdrStandard, hdrFilmMaker,
         hdrVivid, dolbyHdrCinema, dolbyHdrCinemaBright, dolbyHdrDarkAmazon,
         dolbyHdrGame, dolbyHdrStandard, dolbyHdrVivid, dolbyStandard
 
+        Known categories are: picture, aiPicture
+
         Likely not all modes are valid for all tv models.
         """
 
-        params = {"category": "picture", "settings": {"pictureMode": pic_mode}}
+        params = {"category": category, "settings": {"pictureMode": pic_mode}}
 
         return await self.luna_request(ep.LUNA_SET_SYSTEM_SETTINGS, params)
 
     async def set_picture_mode(
-        self, pic_mode, tv_input, dynamic_range="sdr", stereoscopic="2d"
+        self, pic_mode, tv_input, dynamic_range="sdr", stereoscopic="2d", category="picture"
     ):
-        """Set picture mode for specific input, dynamic range and 3d mode.
+        """Set picture mode for specific category, input, dynamic range and 3d mode (OLED C1).
 
         Known picture modes are: cinema, eco, expert1, expert2, game,
-        normal, photo, sports, technicolor, filmMaker, vivid, hdrEffect,  hdrCinema,
-        hdrCinemaBright, hdrExternal, hdrGame, hdrStandard, hdrTechnicolor, hdrFilmMaker,
+        normal, photo, sports, filmMaker, vivid,  hdrCinema,
+        hdrCinemaBright, hdrExternal, hdrGame, hdrStandard, hdrFilmMaker,
         hdrVivid, dolbyHdrCinema, dolbyHdrCinemaBright, dolbyHdrDarkAmazon,
         dolbyHdrGame, dolbyHdrStandard, dolbyHdrVivid, dolbyStandard
 
@@ -1108,23 +1123,35 @@ class WebOsClient:
 
         Known stereoscopic modes are: 2d, 3d
 
+        Known categories are: picture, aiPicture
+
         Likely not all inputs and modes are valid for all tv models.
         """
 
         params = {
-            "category": f"picture${tv_input}.x.{stereoscopic}.{dynamic_range}",
+            "category": f"{category}${tv_input}.x.{stereoscopic}.{dynamic_range}",
             "settings": {"pictureMode": pic_mode},
         }
 
         return await self.luna_request(ep.LUNA_SET_SYSTEM_SETTINGS, params)
 
-    async def set_current_picture_settings(self, settings):
-        """Set picture settings for current picture mode, input, dynamic range and 3d mode.
+    async def set_current_picture_settings(self, settings, category="picture"):
+        """Set picture settings for current category, picture mode, input, dynamic range and 3d mode.
 
-        A possible list of settings and example values are below (not all settings are applicable
-        for all modes and/or tv models):
+        A possible list of settings and OLED C1 example values are below
+        (not all settings are applicable for all modes and/or tv models):
         /etc/palm/defaultSettings.json
 
+        Category: aiPicture
+        -------------------
+
+        "ai_Brightness": "off",
+        "ai_Genre": "off",
+        "ai_Picture": "off"
+
+        Category: picture
+        -----------------
+
         "adjustingLuminance": [
             0,
             0,
@@ -1164,12 +1191,12 @@ class WebOsClient:
         "ambientLightCompensation": "off",
         "backlight": "80",
         "blackLevel": {
-            "ntsc": "low",
+            "ntsc": "auto",
             "ntsc443": "auto",
             "pal": "auto",
             "pal60": "auto",
-            "palm": "low",
-            "paln": "high",
+            "palm": "auto",
+            "paln": "auto",
             "secam": "auto",
             "unknown": "auto"
         },
@@ -1196,7 +1223,7 @@ class WebOsClient:
         "colorManagementSaturationMagenta": "0",
         "colorManagementSaturationRed": "0",
         "colorManagementSaturationYellow": "0",
-        "colorTemperature": "0",
+        "colorTemperature": "-50",
         "contrast": "80",
         "dynamicColor": "off",
         "dynamicContrast": "off",
@@ -1209,7 +1236,6 @@ class WebOsClient:
         "hSharpness": "10",
         "hSize": "0",
         "hdrDynamicToneMapping": "on",
-        "hdrLevel": "medium",
         "localDimming": "medium",
         "motionEyeCare": "off",
         "motionPro": "off",
@@ -1359,17 +1385,17 @@ class WebOsClient:
 
         """
 
-        params = {"category": "picture", "settings": settings}
+        params = {"category": category, "settings": settings}
 
         return await self.luna_request(ep.LUNA_SET_SYSTEM_SETTINGS, params)
 
     async def set_picture_settings(
-        self, settings, pic_mode, tv_input, stereoscopic="2d"
+        self, settings, pic_mode, tv_input, stereoscopic="2d", category="picture"
     ):
-        """Set picture settings for specific picture mode, input, and 3d mode."""
+        """Set picture settings for specific category, picture mode, input, and 3d mode."""
 
         params = {
-            "category": f"picture${tv_input}.{pic_mode}.{stereoscopic}.x",
+            "category": f"{category}${tv_input}.{pic_mode}.{stereoscopic}.x",
             "settings": settings,
         }
 
@@ -1378,13 +1404,13 @@ class WebOsClient:
     async def set_other_settings(self, settings):
         """Set other settings.
 
-        A possible list of settings and example values are below (not all settings are applicable
-        for all tv models/firmwares):
+        A possible list of settings and OLED C1 example values are below
+        (not all settings are applicable for all tv models/firmwares):
         /etc/palm/defaultSettings.json
 
         "amazonHotkeyIsActive": true,
         "appReturn": "",
-        "blackStabilizer": 10,
+        "blackStabilizer": 13,
         "blueLight": "off",
         "care365": {
             "accountName": "",
@@ -1456,8 +1482,8 @@ class WebOsClient:
         "inputOptimization": "auto",
         "isFirstCapture": "true",
         "isfUpdated": "false",
-        "lowLevelAdjustment": 0,
         "lgLogoDisplay": "on",
+        "lowLevelAdjustment": 0,
         "mapping_info": [
             {
                 "movies": {
@@ -1598,6 +1624,7 @@ class WebOsClient:
         "supportAirplay": false,
         "supportBnoModel": false,
         "ueiEnable": "off",
+        "uhdDeepColor": "off",
         "uhdDeepColor8kHDMI1": "off",
         "uhdDeepColor8kHDMI2": "off",
         "uhdDeepColor8kHDMI3": "off",
@@ -1606,13 +1633,12 @@ class WebOsClient:
         "uhdDeepColorAutoStatusHDMI2": "none",
         "uhdDeepColorAutoStatusHDMI3": "none",
         "uhdDeepColorAutoStatusHDMI4": "none",
-        "uhdDeepColor": "off",
         "uhdDeepColorHDMI1": "off",
         "uhdDeepColorHDMI2": "off",
         "uhdDeepColorHDMI3": "off",
         "uhdDeepColorHDMI4": "off",
         "weatherAllowed": false,
-        "whiteStabilizer": 10
+        "whiteStabilizer": 13
 
         """
 
@@ -1623,8 +1649,8 @@ class WebOsClient:
     async def set_option_settings(self, settings):
         """Set option settings.
 
-        A possible list of settings and example values are below (not all settings are applicable
-        for all tv models/firmwares):
+        A possible list of settings and OLED C1 example values are below
+        (not all settings are applicable for all tv models/firmwares):
         /etc/palm/defaultSettings.json
 
         "IPControlSecureKey": "",
@@ -1681,8 +1707,7 @@ class WebOsClient:
         "dbgLogUpload": false,
         "demoFileList": "undefined",
         "demoMode": "on",
-        "disclosureAccepted": false,
-        "disclosureAcceptedVsn": "N/A",
+        "displayMusicWidget": true,
         "eStreamerPosition": "all",
         "emergencyAlert": "on",
         "enableIpControl": "off",
@@ -1698,6 +1723,7 @@ class WebOsClient:
         "freeviewMode": "off",
         "freeviewplay": "off",
         "googleAssistantTTS": "on",
+        "graphicSharpnessLevel": 0,
         "hbbTV": "off",
         "hbbTvDeviceId": "on",
         "hbbTvDnt": "off",
@@ -1705,8 +1731,6 @@ class WebOsClient:
         "helpOnSettings": "on",
         "highContrast": "off",
         "hybridCast": "off",
-        "ibb": "off",
-        "ibbDnt": "off",
         "inputDevicesSupportStatus": {
             "keyboard": true,
             "motionSensor": true,
@@ -1838,33 +1862,72 @@ class WebOsClient:
 
         return await self.luna_request(ep.LUNA_SET_SYSTEM_SETTINGS, params)
 
-    async def get_configs(self, keys=["tv.model.*"]):
+    async def get_configs(self, keys=["tv.model.*"], jsonOutput=False):
         """Get config settings.
 
-        A possible list of keys are below (not all settings are applicable for all tv models):
+        A possible list of keys of OLED C1 are below (not all settings are applicable for all tv models):
+        /etc/configd/layers
 
+        airplay.*
         audio.*
+        broadcast.*
+        com.palm.app.firstuse.*
         com.palm.app.settings.*
         com.palm.app.store-demo.*
+        com.webos.app.connectionwizard.*
+        com.webos.app.factorywin.*
+        com.webos.app.favshows.*
         com.webos.app.home.*
         com.webos.app.igallery.*
         com.webos.app.inputcommon.*
+        com.webos.app.mediadiscovery.*
+        com.webos.app.photovideo.*
         com.webos.app.quickinputpicker.*
         com.webos.app.quicksettings.*
         com.webos.app.systemmusic.*
         com.webos.app.tips.*
+        com.webos.applicationManager.*
         com.webos.authenticationMethods.*
         com.webos.keyaction.*
+        com.webos.memorymanager.*
+        com.webos.service.airplay.*
         com.webos.service.arccontroller.*
+        com.webos.service.attachedstoragemanager.*
+        com.webos.service.cbox.*
+        com.webos.service.datamigrator.*
         com.webos.service.config.*
+        com.webos.service.eim.*
+        com.webos.service.favoriteservice.*
         com.webos.service.fepg.*
+        com.webos.service.hybridtv.*
+        com.webos.service.iepg.*
         com.webos.service.ime.*
         com.webos.service.irdbmanager.*
+        com.webos.service.livepick.*
+        com.webos.service.miracast.*
+        com.webos.service.miracasttx.*
+        com.webos.service.msc.*
+        com.webos.service.nlpmanager.*
         com.webos.service.nop.*
+        com.webos.service.nudge.*
+        com.webos.service.pdm.*
+        com.webos.service.photorenderer.*
+        com.webos.service.preloadmanager.*
+        com.webos.service.rollingscreen.*
         com.webos.service.scd.*
+        com.webos.service.time.*
+        com.webos.service.tnm.*
+        com.webos.service.tvpower.*
+        com.webos.service.utp.*
         com.webos.service.voiceinput.*
+        com.webos.service.voiceinput.*
+        com.webos.service.wampluggable.hbbtv.*
         com.webos.surfacemanager.*
-        inputMap.hdcp22forHDMI.*
+        dvr.*
+        extinput-service.*
+        inputMap.*
+        mediaCapability.*
+        miracast.*
         system.*
         tv.config.*
         tv.conti.*
@@ -1876,8 +1939,8 @@ class WebOsClient:
         """
 
         payload = {"configNames": keys}
-        ret = await self.request(ep.GET_CONFIGS, payload=payload)
-        return ret
+        res = await self.request(ep.GET_CONFIGS, payload=payload)
+        return self.__output_result(res, jsonOutput)
 
     async def set_configs(self, settings):
         """Set config settings.
@@ -1896,10 +1959,10 @@ class WebOsClient:
     async def show_screen_saver(self):
         return await self.luna_request(ep.LUNA_TURN_ON_SCREEN_SAVER, {})
 
-    async def get_system_settings(self, category="option", keys=["audioGuidance"]):
+    async def get_system_settings(self, category="option", keys=["audioGuidance"], jsonOutput=False):
         """Get system settings.
 
-        Most of the settings are not exposed via this call, valid settings:
+        Most of the settings are not exposed via this call, OLED C1 valid settings:
         /usr/palm/services/com.webos.service.apiadapter/adapters/settings/valid-settings.js
 
         "twinTv": [
@@ -1973,14 +2036,14 @@ class WebOsClient:
         """
 
         payload = {"category": category, "keys": keys}
-        ret = await self.request(ep.GET_SYSTEM_SETTINGS, payload=payload)
-        return ret
+        res = await self.request(ep.GET_SYSTEM_SETTINGS, payload=payload)
+        return self.__output_result(res, jsonOutput)
 
     async def get_picture_settings(
-        self, keys=["contrast", "backlight", "brightness", "color"]
+        self, keys=["contrast", "backlight", "brightness", "color"], jsonOutput=False
     ):
-        ret = await self.get_system_settings("picture", keys)
-        return ret["settings"]
+        res = await self.get_system_settings("picture", keys)
+        return self.__output_result(res["settings"], jsonOutput)
 
     async def subscribe_picture_settings(
         self, callback, keys=["contrast", "backlight", "brightness", "color"]
